C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      CHARACTER*(*) FUNCTION ctrim (cstr, cchr, imod)

C @(#)Function: ctrim                Author: R.A. Jansen -- Jun 28, 2009
C @(#)
C @(#)  Purpose: Return as the function value a trimmed version of input
C @(#)    string 'cstr' from which  one or any number of  leading and/or
C @(#)    trailing characters 'cchr' have been stripped.  Integer 'imod'
C @(#)    encodes the following actions:
C @(#)      imod = -2  strip any number of leading 'cchr' from 'cstr'
C @(#)      imod = -1  strip single leading 'cchr' from 'cstr'
C @(#)      imod =  0  strip single leading+trailing 'cchr' from 'cstr'
C @(#)      imod =  1  strip single trailing 'cchr' from 'cstr'
C @(#)      imod =  2  strip any number of trailing 'cchr' from 'cstr'
C @(#)    Common examples of such characters are single or double quotes
C @(#)    (CHAR(39) or CHAR(34)),   zeros ('0' or CHAR(48)),  or leading
C @(#)    blank spaces (CHAR(32)). Stripped characters are replaced with
C @(#)    blanks,  after which the remaining non-blank portion of 'cstr'
C @(#)    is left-adjusted on character 1  and returned as  the function
C @(#)    value.
C @(#)
C @(#)  Calling sequence:  sstr = ctrim(cstr,cchr,imod)  ,  where string
C @(#)    'cstr' can be of arbitrary declared length, 'cchr' is a single
C @(#)    character and 'imod' an integer with valid range [-2..2]. This
C @(#)    function has neither input nor exit error status.
C @(#)
C @(#)  Dependencies:     clen
C @(#)
C @(#)  Revision history: 
C @(#)    Jun 19, 2009 [RAJ] -- Initial version of this routine;  strips
C @(#)                          any number of leading or trailing chars,
C @(#)                          or both, if present; leading spaces were
C @(#)                          not considered to be significant.
C @(#)    Jun 28, 2009 [RAJ] -- Changed coding of imod values; added new
C @(#)                          modes to specify whether to strip single
C @(#)                          or any number of 'cchr' characters  from
C @(#)                          'cstr'; leading spaces now significant.
C @(#)------------------------------------------------------------------

      CHARACTER*(*) cstr, cchr*1
      INTEGER	imod, clen, i, j

C --- Initialize output to input string...
      ctrim = cstr

C --- Return if the 'imod' is out of range [-2..2] ...
      IF (imod.LT.-2.OR.imod.GT.2) RETURN

C --- Return if the input string is empty or blank...
      j = clen(cstr)
      IF (j.EQ.0) RETURN

C --- Strip the leading and/or trailing character(s) 'cchr' from 'cstr',
C     as specified thru the value integer switch 'imod'...
      IF (imod.EQ.-2) THEN
C        Remove any number of leading instances of the character 'cchr'
         DO i = 1,j
            IF (cstr(i:i).NE.cchr) RETURN
            ctrim((j-i+1):(j-i+1)) = CHAR(32)
            IF (j.GT.1) ctrim(1:(j-i)) = cstr((i+1):j)
         ENDDO

      ELSE IF (imod.EQ.-1) THEN
C        Remove a single leading character 'cchr', if present
         IF (cstr(1:1).EQ.cchr) THEN
            ctrim(j:j) = CHAR(32)
            IF (j.GT.1) ctrim(1:(j-1)) = cstr(2:j)
         ENDIF

      ELSE IF (imod.EQ.0) THEN
C        Remove a single leading + trailing character 'cchr', if present
         IF (cstr(1:1).EQ.cchr) THEN
            ctrim(j:j) = CHAR(32)
            IF (j.GT.1) ctrim(1:(j-1)) = cstr(2:j)
         ENDIF
         IF (cstr(j:j).EQ.cchr) THEN
            ctrim((j-1):(j-1)) = CHAR(32)
         ENDIF

      ELSE IF (imod.EQ.1) THEN
C        Remove a single trailing character 'cchr', if present
         IF (cstr(j:j).EQ.cchr) THEN
            ctrim(j:j) = CHAR(32)
         ENDIF

      ELSE
C        Remove any number of trailing instances of the character 'cchr'
         DO i = j,1,-1
            IF (cstr(i:i).NE.cchr) RETURN
            ctrim(i:i) = CHAR(32)
         ENDDO
      ENDIF

      RETURN
      END


