C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE manual()

C @(#)Subroutine: manual             Author: R.A. Jansen -- Jul 30, 2008
C @(#)
C @(#)  Purpose: Write a short manual page showing the proper syntax and
C @(#)    command-line options to program 'mkmask'.
C @(#)
C @(#)  Calling sequence: CALL manual()
C @(#)
C @(#)  Dependencies:  clen, error, fwritc; 'devices.inc'
C @(#)
C @(#)  Note:  the path to the man-page text file is presently hardcoded
C @(#)    and ought to be changed or replaced with  a global manpath and
C @(#)    file name when porting this routine.
C @(#)
C @(#)  Revision history:
C @(#)    Jul 31, 2008 [RAJ] -- added internal error status variable due
C @(#)                          to changed calling sequence of 'fwritc'.
C @(#)    Feb 12, 2013 [RAJ] -- modified Purpose and the manual filename
C @(#)                          as appropriate for 'mkmask'.
C @(#)    Feb 13, 2013 [RAJ] -- added explicit error message in case of
C @(#)                          failure to read the man page.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Learn about default devices...
      INCLUDE	'devices.inc'

C --- Declaration of input variables...
C     (none)

C --- Declaration of local variables...
      CHARACTER*(80) mfile, cline
      INTEGER	iunit, clen, ierr
      LOGICAL	ok, busy

C --- Initialize...
      ierr = 0

C --- Name of text file containing the manual...
      mfile = 'mkmask.man'

C --- Check whether the manual file is indeed present...
      INQUIRE(FILE=mfile(1:clen(mfile)),EXIST=ok)
      IF (.NOT.ok) THEN
         cline = 'ERROR: '//mfile(1:clen(mfile))//' not found!'
         CALL fwritc(STDOUT,cline,ierr)
         RETURN
      ENDIF

C --- Find an available file unit number...
      DO iunit=STDOFIL,99
         INQUIRE (UNIT=iunit,OPENED=busy)
         IF (.NOT.busy) GOTO 1
      ENDDO
      CALL error('manual','could not find any free logical device unit')

C --- Open the manual file for reading...
1     OPEN(UNIT=iunit,FILE=mfile(1:clen(mfile)),STATUS='OLD',ERR=9)

C --- Print the manual page...
2     READ(iunit,'(A)',END=3) cline
      CALL fwritc(STDOUT,cline,ierr)
      GOTO 2

C --- Close the manual file...
3     CLOSE(UNIT=iunit)
      RETURN

9     CALL error('manual','failed to read '//mfile(1:clen(mfile)))
      RETURN
      END


