C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE maskpoint (ityp, regstr, pix, ncol, nrow, mval, ierr)

C @(#)Subroutine: maskpoint            Author: R.A. Jansen -- Apr 9 2013
C @(#)
C @(#)  Purpose: parse a previously verified region descriptor string in
C @(#)    ASCII pixel list format when its type matches that of a region
C @(#)    encompassing a single pixel (ie., 'ityp'=1) or exit otherwise,
C @(#)    and update the input pixel array  by adding the specified mask
C @(#)    value if non-zero,  or setting the specified pixel region to 0
C @(#)    otherwise.  An out-of-bounds pixel descriptor will be ignored.
C @(#)    If an error condition is detected, error status 'ierr' will be
C @(#)    non-zero upon exit. 
C @(#)  
C @(#)  Calling Sequence:
C @(#)    CALL maskpoint (ityp, regstr,  pix, ncol, nrow,  mval, ierr) ,
C @(#)    where 'ityp' is an integer, and 'regstr' is a character string
C @(#)    of arbitrary declared length.   A valid descriptor string con-
C @(#)    sists of two SPACE, TAB, or COMMA-separated numeric values 'x'
C @(#)    and 'y'.  Their values will be rounded to the nearest integer,
C @(#)    when not integer already.  'pix' is an integer valued array of
C @(#)    size 'ncol'x'nrow' elements (with 'ncol' and 'nrow' integers).
C @(#)    Both 'mval' and 'ierr' are integers.
C @(#)
C @(#)  Dependencies: several routines from my  'rjgen'  library:  clen,
C @(#)    cinit, creadr, error, parse
C @(#)
C @(#)  Revision history:
C @(#)    Apr  9 2013 [RAJ] -- Initial version of this routine.
C @(#) -----------------------------------------------------------------

      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER*(*) regstr
      INTEGER	nrow, ncol, pix(nrow*ncol)
      INTEGER	ityp, mval, ierr

C --- External functions...
      INTEGER	clen

C --- Other program variables...
      CHARACTER delim*1, cpar*80
      REAL	rval
      INTEGER	lpar, k, m, ix, iy

C     ------------------------------------------------------------------

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C --- Return for a region descriptor string of the wrong type...
      IF (ityp.NE.1) RETURN


C --- Parse the two numeric values from the region descriptor string...
      delim = CHAR(32)
      k     = 0
      m     = clen(regstr)

C     write(*,*)'DEBUG(maskpoint): [entering] clen(regstr)=',m

      DO WHILE (m.GT.0)
         CALL cinit(cpar)
         lpar = 0
         CALL parse(regstr,delim,cpar,lpar)
         IF (lpar.GT.0) THEN
            CALL creadr(cpar(1:lpar),rval,ierr)
         ELSE
            ierr = 1
         ENDIF
         IF (ierr.NE.0) THEN
            CALL error('maskpoint','parsing POINT descriptor')
            ierr = 1
            RETURN
         ENDIF

         k = k + 1
         IF (k.EQ.1) ix = NINT(rval)
         IF (k.EQ.2) iy = NINT(rval)

         m = clen(regstr)
      ENDDO

C     Test that we successfully parsed two and only two numeric values
C     from the regions descriptor string...
      IF (k.NE.2) THEN
         CALL cinit(cpar)
         cpar = 'parsing POINT descriptor: nfields != 2'
         CALL error('maskpoint',cpar)
         ierr = 2
         RETURN
      ENDIF

C     write(*,*)'DEBUG(maskpoint): read a pair of x,y coordinates'


C --- Update the pixel array if the specified pixel is within bounds...
C     write(*,*)'DEBUG(maskpoint):  updating pixel array...'
      IF (     ix.GE.1.AND.ix.LE.ncol
     +    .AND.iy.GE.1.AND.iy.LE.nrow) THEN
         IF (mval.EQ.0) THEN
            pix(ix+(iy-1)*ncol) = 0
         ELSE
            pix(ix+(iy-1)*ncol) = pix(ix+(iy-1)*ncol) + mval
         ENDIF
      ENDIF


      RETURN
      END

