C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE rjfgcomm (crec, ccom, ilen, idbg, ierr)

C @(#)Subroutine: rjfgcomm           Author: R.A. Jansen -- Sep 21, 2009
C @(#)
C @(#)  Purpose:  Read the comment from a FITS header record 'crec' that
C @(#)    is already known to be a comment or formatting record,  return
C @(#)    it through 'ccom' and its actual (rather than declared) length
C @(#)    through 'ilen'.  The comment record may be blank on input.  If
C @(#)    verbosity level 'idbg'>0,  additional messages may be printed.
C @(#)    Error status 'ierr'  will be non-zero upon exit,  if any error
C @(#)    is detected.  Its value (if >2000) uniquely identifies a known
C @(#)    error condition.
C @(#)
C @(#)  Calling sequence:
C @(#)    CALL rjfgcomm(crec, ccom, ilen, idbg, ierr),  where 'crec' and
C @(#)    'ccom' are strings with declared lengths of 80 characters, and
C @(#)    'ilen','idbg' and 'ierr' are all integers.
C @(#)
C @(#)  Note: this task is meant to be run after either 'rjfgkwrd' (when
C @(#)    'lcom' is returned as true) or 'rjfvkval' (if the return value
C @(#)    for 'ityp' is 0).
C @(#)
C @(#)  Dependencies:	clen, cinit
C @(#)
C @(#)  Revision history:
C @(#)    Jun 27, 2009 [RAJ] -- Initial draft version of this routine.
C @(#)    Sep 21, 2009 [RAJ] -- Major redink; changed calling sequence.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER	crec*80, ccom*80
      INTEGER	ilen, idbg, ierr

C --- Declaration of local variables...
      CHARACTER dbid*19, cc
      INTEGER	clen, klen, ic, j

C     'ib' and 'it' are shorthand integer equivalents in the ASCII col-
C     lating sequence of the space and tilde characters, respectively...
      INTEGER	ib, it

C     ------------------------------------------------------------------

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C --- Initialize the debugging ID string...
      dbid  = 'DEBUG(rjfgcomm): '

C --- Initialize the output variable...
      CALL cinit(ccom)
      ilen = -1
 
C --- Initialize the local variables...
      ib = ICHAR(' ')
      it = ICHAR('~')

C --- Test that byte 9 in 'crec' indeed contains a blank (captures user
C     error of calling 'rfjgcomm' before 'rjfgkwrd' or 'rjfvkval')...
      cc = crec(9:9)
      ic = ICHAR(cc)
      IF (ic.NE.ib) THEN
C        Not a blank, therefore not a comment record!
         IF (idbg.GT.0) WRITE(*,*) dbid//
     +      'header record is not a comment record'
         ierr = 2621
         GOTO 9
      ENDIF


C --- Test on-the-fly for any illegal characters outside the restricted
C     ASCII set while copying verbatim the comment text (starting from
C     byte 10) to 'ccom'...
      klen = clen(crec)

C     The following loop must not be executed unless klen>9 ...
      DO j=10,klen
         cc = crec(j:j)
         ic = ICHAR(cc)
         IF (ic.LT.ib.OR.ic.GT.it) THEN
C           Illegal character outside the restricted ASCII set!
            IF (idbg.GT.0) WRITE(*,*) dbid//'comment text contains '//
     +         'embedded non-printable character(s)'
            ierr = 2622
         ENDIF
         ccom((j-9):(j-9)) = cc
      ENDDO

C --- Return the actual length of the comment string...
      ilen = clen(ccom)


9     IF (idbg.GT.2) WRITE(*,*) dbid//crec(1:clen(crec))
      IF (idbg.GT.1) WRITE(*,*) dbid//'on exit, ierr = ',ierr

      RETURN
      END


