C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++   

      SUBROUTINE rjfghblk (iunit, iblk, block, idbg, ierr)

C @(#)Subroutine: rjfghblk            Author: R.A. Jansen -- Jun 18, 2009
C @(#)
C @(#)  Purpose:  Read logical 2880-byte block number 'iblk' from a FITS
C @(#)    file that is already open for direct access  at logical device
C @(#)    'iunit' and, if successful, return it thru 2880-byte character
C @(#)    string 'block'.  If integer verbosity level 'idbg'>0, additio-
C @(#)    nal messages will be printed.  If a warning or error condition
C @(#)    was detected,  integer error status 'ierr' will be non-zero on
C @(#)    exit:  a value of -1 indicates that the last block in the file
C @(#)    was read up to EOF (not necessarilly an error);  a value >2000
C @(#)    uniquely identifies a known error condition.
C @(#)
C @(#)  Calling sequence: CALL rjfghblk(iunit, iblk, block, idbg, ierr),
C @(#)    where 'iunit' and 'iblk' are integers,  'block' is a 2880-byte
C @(#)    character string, and 'idbg' and 'ierr' are both integers.
C @(#)
C @(#)  Dependencies:	cinit, clen
C @(#)
C @(#)  Revision history:
C @(#)    Aug  5, 2008 [RAJ] -- Initial version (was part of 'chkfits').
C @(#)    Jun 17, 2009 [RAJ] -- Split off repeat code from 'chkfits' and
C @(#)                          'chkgeis' and 'exthdr';  generalized and
C @(#)                          expanded it to a low-level routine.
C @(#)    Jun 18, 2009 [RAJ] -- Updated and expanded the documentation.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER	block*2880
      INTEGER	iunit, iblk, idbg, ierr

C --- Declaration of local variables...
      CHARACTER	dbid*19
      INTEGER	clen

C     ------------------------------------------------------------------

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C     Initialize the debugging ID string...
      dbid  = 'DEBUG(rjfghblk): '

C     Return for non-positive direct access block number...
      IF (iblk.LT.1) THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//
     +      'invalid direct access record number (iblk < 1) on input.'
         ierr = 2051
         RETURN
      ENDIF

C --- Try reading the requested 2880-byte direct access record...
      IF (idbg.GT.0) WRITE(*,*) dbid//'try reading 2880b-block #',iblk
      CALL cinit(block)
      READ(iunit,'(A)',REC=iblk,IOSTAT=ierr) block

C --- Diagnose success/failure...
      IF (ierr.EQ.0) THEN
C        Successfully read the requested 2880-byte block.
         IF (idbg.GT.0) WRITE(*,*) dbid//'read successful; last = F'
      ELSE IF (ierr.EQ.-1) THEN
C        Either successfully read the last 2880-byte block in this file
C        or tried to read past EOF: test which is the case...
         IF (clen(block).GE.3) THEN
            IF (idbg.GT.0) WRITE(*,*) dbid//'read successful; last = T'
         ELSE
            IF (idbg.GT.0) WRITE(*,*) dbid//'read failed; last = T'
            ierr = 2052
         ENDIF
      ELSE
C        Failed to read requested 2880-byte block: unexpected EOF.
         IF (idbg.GT.0) WRITE(*,*) dbid//'read failed; last = F'
         ierr = 2053
      ENDIF

      IF (idbg.GT.1) WRITE(*,*) dbid//'on exit, ierr = ',ierr

      RETURN
      END


