C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE rjfgkcom (crec, comm, ityp, idbg, ierr)

C @(#)Subroutine: rjfgkcom           Author: R.A. Jansen -- Oct 25, 2009
C @(#)
C @(#)  Purpose: Read a keyword comment 'comm' from a FITS header record
C @(#)    'crec'  containing a keyword value of type 'ityp' (as returned
C @(#)    by 'rjfvkval').  If no keyword comment is present, 'comm' will
C @(#)    be blank upon exit (this includes the case where  'crec'  is a
C @(#)    comment record).  If verbosity level 'idbg'>0, additional mes-
C @(#)    sages may be printed.  Should any error condition be detected,
C @(#)    error status 'ierr' will be non-zero upon exit.  Its value (if
C @(#)    >2000) uniquely identifies a known error condition.
C @(#)
C @(#)  Calling sequence:  CALL rjfgkcom (crec, comm, ityp, idbg, ierr),
C @(#)    where 'crec' and 'comm' are char strings with declared lengths
C @(#)    of 80 characters; 'ityp','idbg' and 'ierr' are all integers.
C @(#)
C @(#)  Note:  this task is meant to be run after 'rjfvkval'  and one of
C @(#)    the 'rjfgkval*' family of routines.
C @(#)
C @(#)  Dependencies:	clen, cinit, cidx, lenc
C @(#)
C @(#)  Revision history:
C @(#)    Oct 25, 2009 [RAJ] -- Initial version of this routine.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER	crec*80, comm*80
      INTEGER	ityp, idbg, ierr

C --- Declaration of local variables...
      CHARACTER dbid*19, ctmp*80, cc, cq
      INTEGER	clen, i, j, k

C     The following variables are shorthand integer equivalents in the
C     ASCII collating sequence of space, equals sign, parenthesis open,
C     quote, and slash, respectively...
      INTEGER	ib, ie, io, iq, is

C     Flag 'lclos' is raised when a closing quote is found (strings)...
      LOGICAL	lclos

C     ------------------------------------------------------------------

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C --- Initialize the debugging ID string...
      dbid  = 'DEBUG(rjfgkcom): '

C --- Initialize local variables...
      CALL cinit(ctmp)
      CALL cinit(ccom)
      ib  = ICHAR(' ')
      ie  = ICHAR('=')
      io  = ICHAR('(')
      iq  = 39
      is  = ICHAR('/')
      lclos = .FALSE.

C --- Return a blank keyword comment string 'comm' (possibly a warning),
C     when the input header record is a comment record...
      cc = crec(9:9)
      ic = ICHAR(cc)
      IF (ic.NE.ie .OR. ityp.EQ.0) THEN
C        No keyword value and no keyword comment in this comment record!
         IF (idbg.GT.1) WRITE(*,*) dbid//'Warning: comment record, '//
     +      'contains neither keyword value nor keyword comment'
         GOTO 9
      ENDIF

C --- Assign the nominal value portion of the header record to 'ctmp'.
C     In v3.0 of the FITS standard, free-format values are allowed to
C     start anywhere after character 10 ...
      ctmp(1:71) = crec(10:80)
      k = clen(ctmp)

C --- Test the first non-blank character in 'ctmp'...
      i = lenc(ctmp)
      cc = ctmp(i:i)
      ic = ICHAR(cc)
      IF (ic.EQ.is .OR. ityp.EQ.-1) THEN
C        First non-blank character is 1st character of keyword comment..
         j = i
         comm(1:(k-j+1)) = ctmp(j:k)
         IF (ic.NE.is) THEN
C           Prepend the recommended '/ '...
            k = k + 2
            comm(3:80) = comm(1:78)
            comm(1:2) = '/ '
         ENDIF
         GOTO 9

      ELSE IF (ityp.EQ.2) THEN
C        Boolean keyword value, right-adjusted on byte 30...
         j = cidx(ctmp(i:k),'/')
         comm(1:(k-(i+j))) = ctmp((i+j-1):k)
         GOTO 9

      ELSE IF (ityp.GE.3 .AND. ityp.LE.7) THEN
C        Numeric keyword values, right-adjusted on byte 30...
         j = cidx(ctmp(i:k),'/')
         comm(1:(k-(i+j))) = ctmp((i+j-1):k)
         GOTO 9

      ELSE IF (ityp.EQ.1 .OR. ityp.EQ.8) THEN
         IF (ityp.EQ.1) THEN
C           First non-blank character is the opening quote of a string
C           valued keyword value; find the closing quote...
            cq = CHAR(iq)
         ELSE
C           First non-blank character is the opening parenthesis of a
C           complex valued keyword value; find the closing parenthesis..
            cq = ')'
         ENDIF

         k = cidx(ctmp(i:k),cq)





      ENDIF


9     IF (idbg.GT.2) WRITE(*,*) dbid//crec(1:clen(crec))
      IF (idbg.GT.1) WRITE(*,*) dbid//comm(1:clen(comm))
      IF (idbg.GT.1) WRITE(*,*) dbid//
     +   'i=',i,', j=',j,', k=',k,'. On exit, ierr = ',ierr

      RETURN
      END


