C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++   

      SUBROUTINE rjfphblk (block, iunit, iblk, idbg, ierr)

C @(#)Subroutine: rjfphblk            Author: R.A. Jansen -- Jul  2, 2009
C @(#)
C @(#)  Purpose: Write a logical 2880-byte character string 'block' from
C @(#)    memory  to direct access record  number 'iblk'  in a FITS file
C @(#)    that is already open for direct write access at logical device
C @(#)    'iunit'. If integer verbosity level 'idbg'>0, additional mess-
C @(#)    ages will be printed.  Should an error condition  be detected,
C @(#)    then integer error status 'ierr' will be non-zero on exit. Its
C @(#)    value (if >2000) uniquely identifies a known error condition.
C @(#)
C @(#)  Calling sequence: CALL rjfphblk(block, iunit, iblk, idbg, ierr),
C @(#)    where 'block' is a 2880-byte character string, 'iunit','iblk',
C @(#)    'idbg', and 'ierr' are all integers.
C @(#)
C @(#)  Note:  The calling routine must ensure that the requested direct
C @(#)    access record number  'iblk'  is sensible, to avoid corrupting
C @(#)    an existing FITS file. This routine was designed to write FITS
C @(#)    header blocks, not (yet?) the binary data stream.
C @(#)
C @(#)  Dependencies:	clen
C @(#)
C @(#)  Revision history:
C @(#)    Jul  2, 2009 [RAJ] -- Initial version of this routine.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER	block*2880
      INTEGER	iunit, iblk, idbg, ierr

C --- Declaration of local variables...
      CHARACTER	dbid*19, cacc*8
      INTEGER	clen, nxt, recl
      LOGICAL	lopen
C     ------------------------------------------------------------------

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C     Initialize the debugging ID string...
      dbid  = 'DEBUG(rjfphblk): '

C     Return for non-positive direct access block number...
      IF (iblk.LT.1) THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//
     +      'invalid direct access record number (iblk < 1) on input.'
         ierr = 2061
         RETURN
      ENDIF

C --- Test that a file is indeed attached to the specified logical
C     device unit and is open for direct access; 
C     Inquire what the last direct access record in the file is
      INQUIRE (iunit, OPENED=lopen, DIRECT=cacc, RECL=recl, NEXTREC=nxt)
      IF (.NOT.lopen) THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//'specified logical device un'//
     +      'it number is not attached to an open file'
         ierr = 2062
         RETURN
      ENDIF
      IF (cacc(1:clen(cacc)).NE.'YES') THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//'direct access is not allowe'//
     +      'd for the file attached to iunit=',iunit
         ierr = 2063
         RETURN
      ENDIF
      IF (recl.NE.2880) THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//'file attached to the specif'//
     +      'ied logical device unit has incorrect record length'
         ierr = 2064
         RETURN
      ENDIF
      IF (iblk.GT.nxt) THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//'requested direct access '//
     +      'record number ',iblk,' > last_record + 1'
         ierr = 2065
         RETURN
      ENDIF

C --- Try writing 'block' to the requested direct access record...
      IF (idbg.GT.0) WRITE(*,*) dbid//'try writing 2880b-block #',iblk
      WRITE(iunit,'(A2880)',REC=iblk,IOSTAT=ierr) block

C --- Diagnose success/failure...
      IF (ierr.EQ.0) THEN
C        Successfully wrote the 2880-b block to the requested record...
         IF (idbg.GT.0) WRITE(*,*) dbid//'write successful'
      ELSE
C        Failed to write the 2880-b block to the requested record...
         IF (idbg.GT.0) WRITE(*,*) dbid//'write failed'
         ierr = 2066
      ENDIF

      IF (idbg.GT.1) WRITE(*,*) dbid//'on exit, ierr = ',ierr

      RETURN
      END


